@@ -1,6 +1,6 @@
-from .models.SQLBatch import SQLBatch
-from .models.SQLStatement import SQLStatement
-from .buffer.ResultBufferStrategy import ResultBufferStrategy
+from .model.SQLBatch import SQLBatch
+from .model.SQLStatement import SQLStatement
+from .persistence.ResultPersistenceStrategy import ResultPersistenceStrategy
 from .storage.StorageStrategyTemplate import StorageStrategyTemplate
 from .storage.LocalStorageStrategy import LocalStorageStrategy
 from .storage.AWSStorageStrategy import AWSStorageStrategy
@@ -9,7 +9,7 @@ from .storage.InMemoryProcedureStorageStrategy import InMemoryProcedureStorageSt
 __all__ = [
     'SQLBatch',
     'SQLStatement',
-    'ResultBufferStrategy',
+    'ResultPersistenceStrategy',
     'StorageStrategyTemplate',
     'LocalStorageStrategy',
     'AWSStorageStrategy',
